@@ -2,17 +2,17 @@
 #define QT_FEATURE_webengine_embedded_build -1
 #define QT_FEATURE_webengine_arm_thumb -1
 #define QT_FEATURE_webengine_bison 1
+#define QT_FEATURE_webengine_printing_and_pdf 1
 #define QT_FEATURE_webengine_flex 1
 #define QT_FEATURE_webengine_gperf 1
 #define QT_FEATURE_webengine_host_pkg_config 1
 #define QT_FEATURE_webengine_kerberos -1
-#define QT_FEATURE_webengine_noexecstack 1
 #define QT_FEATURE_webengine_pepper_plugins 1
 #define QT_FEATURE_webengine_poppler_cpp 1
-#define QT_FEATURE_webengine_printing_and_pdf 1
 #define QT_FEATURE_webengine_proprietary_codecs 1
 #define QT_FEATURE_webengine_pulseaudio 1
 #define QT_FEATURE_webengine_python2 1
+#define QT_FEATURE_webengine_qml 1
 #define QT_FEATURE_webengine_sanitizer -1
 #define QT_FEATURE_webengine_system_dbus 1
 #define QT_FEATURE_webengine_system_opus 1
@@ -46,10 +46,9 @@
 #define QT_FEATURE_webengine_system_xi 1
 #define QT_FEATURE_webengine_system_xtst 1
 #define QT_FEATURE_webengine_system_zlib 1
-#define QT_FEATURE_webengine_testsupport -1
-#define QT_FEATURE_webengine_ui_delegates 1
 #define QT_FEATURE_webengine_v8_snapshot 1
 #define QT_FEATURE_webengine_v8_snapshot_support 1
 #define QT_FEATURE_webengine_webrtc 1
+#define QT_FEATURE_webengine_widgets 1
 #define QT_FEATURE_webengine_win_compiler64 -1
 #define QT_FEATURE_webengine_winversion -1
